=begin meta 
kind => "text/plain"
=end meta
=cut
print "Hello World!\n";
print "path = ",$context->response->generator->get_property('path'),"\n";
